#!/usr/bin/env python3
# THIS "versionfile" IS GENERATED BY version-pioneer-0.0.1
# by evaluating the original versionscript and storing the computed versions as a constant.

def get_version_dict():
    return {'version': '0.0.1', 'full_revisionid': 'b4afde7271b0f311cf5a7c26ab756b50959ce4c4', 'dirty': False, 'error': None, 'date': '2024-12-25T14:24:27+0000'}


if __name__ == "__main__":
    import json

    print(json.dumps(get_version_dict()))